from flask import Flask, render_template, jsonify
app = Flask(__name__)
 
@app.route("/")
def hello():
    return render_template('index.html')

@app.route("/calendar")
def getCalendar():
    return render_template('calendar.html')

@app.route("/weather/<city>")
def getWeather(city):
    import geocoder
    g = geocoder.ip('me')
    print(g.latlng)

    from weather import Weather, Unit
    weather = Weather(unit=Unit.CELSIUS)
    location = weather.lookup_by_location(city)
    # print(location.print_obj)
    # print(condition.text)
    # return jsonify(location.print_obj)
    # location.astronomy
    # print("Temp:", location.item['description'])
    # print("Condition:", location.condition.text)
    # print(location.forecast[0].text)

    if(location):
        weatherDetails = {
            "City": location.location.city,
            "State": location.location.region,
            "Country": location.location.country,
            "Sunrise": location.astronomy['sunrise'],
            "Sunset": location.astronomy['sunset'],
            "Humidity": location.atmosphere['humidity'],
            "Temp": location.condition.temp,
            "Condition": location.condition.text
        }
        return render_template('weather.html', weather=weatherDetails)
    return ""
    # return jsonify(location.print_obj)
    # return location.forecast

if __name__ == "__main__":
    # app.run(ssl_context='adhoc')
    app.run(port=5000)


from setuptools import setup

setup(
    name='Smart Mirror',
    version='1.1',
    long_description=__doc__,
    packages=['smart_mirror'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'Flask>=1.0.2',
        'geocoder>=1.38.1',
        'Jinja2>=2.10',
        'weather-api==1.0.4'
    ],

    # metadata to display on PyPI
    author="Kushal Katta",
    author_email="kushal@katta.xyz",
    description="Smart Mirror Project",
    keywords="smart mirror intelligent system home automation",
    url="http://katta.xyz/SmartMirror/",
    project_urls={
        # "Bug Tracker": "https://bugs.example.com/HelloWorld/",
        # "Documentation": "https://docs.example.com/HelloWorld/",
        "Source Code": "https://github.com/KushalKatta/SmartMirror",
    }

    # could also include long_description, download_url, classifiers, etc.
)